summaryrefslogtreecommitdiff
path: root/lib/mkstemp.c
diff options
context:
space:
mode:
authorEric Blake <ebb9@byu.net>2009-11-17 11:53:14 -0700
committerEric Blake <ebb9@byu.net>2009-11-17 22:15:29 -0700
commit83e045030538b7838367305c0b92c7c756c90651 (patch)
tree97f5346f55106b512dfee252360021cf4b7065d3 /lib/mkstemp.c
parent89fe4c9d24e052d1947575379792613eb82f37cb (diff)
downloadgnulib-83e045030538b7838367305c0b92c7c756c90651.tar.gz
mkstemp: avoid conflict with C++ keyword template
Just because glibc uses K&R, and uses template as an identifier, doesn't mean we have to. * lib/mkdtemp.c (mkdtemp): Change spelling of template. * lib/mkostemp.c (mkostemp): Likewise. * lib/mkostemps.c (mkostemps): Likewise. * lib/mkstemp.c (mkstemp): Likewise. * lib/mkstemps.c (mkstemps): Likewise. Signed-off-by: Eric Blake <ebb9@byu.net>
Diffstat (limited to 'lib/mkstemp.c')
-rw-r--r--lib/mkstemp.c9
1 files changed, 4 insertions, 5 deletions
diff --git a/lib/mkstemp.c b/lib/mkstemp.c
index 684c98331c..dda0400948 100644
--- a/lib/mkstemp.c
+++ b/lib/mkstemp.c
@@ -35,13 +35,12 @@
# define __GT_FILE 0
#endif
-/* Generate a unique temporary file name from TEMPLATE.
- The last six characters of TEMPLATE must be "XXXXXX";
+/* Generate a unique temporary file name from XTEMPLATE.
+ The last six characters of XTEMPLATE must be "XXXXXX";
they are replaced with a string that makes the file name unique.
Then open the file and return a fd. */
int
-mkstemp (template)
- char *template;
+mkstemp (char *xtemplate)
{
- return __gen_tempname (template, 0, 0, __GT_FILE);
+ return __gen_tempname (xtemplate, 0, 0, __GT_FILE);
}